<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <source>OpenSSH Authentication Passphrase request</source>
        <translation>Požadavek z OpenSSH ověření na heslovou frázi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <source>Enter your SSH passphrase for request:</source>
        <translation>Zadejte heslovou frázi pro SSH:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="51"/>
        <source>unknown request</source>
        <translation>neznámý požadavek</translation>
    </message>
</context>
</TS>
